@@ -85,6 +85,9 @@ void CopyCD::slot_start(){
 	config->setGroup("CD-Writer");
 	(*process) << config->readEntry("Device");
 
+	//Set Burn-Proof
+	if( config->readNumEntry("BurnProof") == true ) (*process) << "driveropts=burnproof";
+
 	//Set CD-Writer Options to KProcess
 	if( QCheckBox_Simulate->isChecked() ) (*process) << "-dummy";
 	if( QCheckBox_ignoresize->isChecked() ) (*process) << "-ignsize";
@@ -111,6 +114,9 @@ void CopyCD::slot_start(){
 	   	if( rc == 2 ) (*process) << "speed=4";
 	   	if( rc == 3 ) (*process) << "speed=6";
 	   	if( rc == 4 ) (*process) << "speed=8";
+	   	if( rc == 4 ) (*process) << "speed=10";
+	   	if( rc == 4 ) (*process) << "speed=12";
+	   	if( rc == 4 ) (*process) << "speed=16";
 	   	}
 
 	//Set the CD-Reader
@@ -187,7 +193,12 @@ void CopyCD::slotRecStderr( KProcess *, char *buffer, int buflen) {
 							BufferProgress -> setProgress( load );
 
 							if( wrote ) {
-								StatusLabel -> setText( i18n("Writing to CD...") );
+								if( QCheckBox_Simulate->isChecked() ) {
+									StatusLabel -> setText( i18n("Writing to CD in dummy mode...") );
+								}
+								else {
+									StatusLabel -> setText( i18n("Writing to CD...") );
+								}
 							}
 				
 							if( ( total == wrote ) && ( QCheckBox_Simulate->isChecked() == false )) {
