@@ -225,7 +225,10 @@ void MasterCD::slot_writeCD(){
 	config->setGroup("CD-Writer");
 	(*process) << config->readEntry("Device");
 
-	//Set CD-Writer Options to K(*process)
+	//Set Burn-Proof
+	if( config->readNumEntry("BurnProof") == true ) (*process) << "driveropts=burnproof";
+
+	//Set CD-Writer Options to KProcess
 	if( QCheckBox_EjectCD->isChecked() ) (*process) << "-eject";
 	if( QCheckBox_Force->isChecked() ) (*process) << "-force";
 	if( QCheckBox_Multisession->isChecked() ) (*process) << "-multi";
@@ -253,6 +256,9 @@ void MasterCD::slot_writeCD(){
 	   	if( rc == 2 ) (*process) << "speed=4";
 	   	if( rc == 3 ) (*process) << "speed=6";
 	   	if( rc == 4 ) (*process) << "speed=8";
+	   	if( rc == 4 ) (*process) << "speed=10";
+	   	if( rc == 4 ) (*process) << "speed=12";
+	   	if( rc == 4 ) (*process) << "speed=16";
 	   	}
 
 	//Set the Image
@@ -429,7 +435,12 @@ void MasterCD::slot_burnRecStderr(KProcess *, char *buffer, int buflen) {
 							}
 							
 							if( wrote ) {
-								procoutdlg.StatusLabel->setText( i18n("Writing to CD...") );
+								if( QCheckBox_Simulate->isChecked() ) {
+									procoutdlg.StatusLabel -> setText( i18n("Writing to CD in dummy mode...") );
+								}
+								else {
+									procoutdlg.StatusLabel -> setText( i18n("Writing to CD...") );
+								}
 							}
 
 						}
