@@ -9,6 +9,7 @@
 #include <stdio.h>
 
 #include <qcombobox.h>
+#include <qcheckbox.h>
 #include <qlabel.h>
 
 #include <kconfig.h>
@@ -45,6 +46,7 @@ Setup::Setup(QWidget *parent, const char *name ) : Setup_GUI(parent,name) {
 
 	config->setGroup("CD-Writer");
 	QComboBox_cdwriterdev->setCurrentItem( config->readNumEntry("Index") );
+	QCheckBox_BurnProof->setChecked( config->readNumEntry("BurnProof") );
 
 	config->setGroup("CD-Reader");
 	QComboBox_cdreaderdev->setCurrentItem( config->readNumEntry("Index") );
@@ -64,6 +66,7 @@ void Setup::slot_save(){
 	config->writeEntry("Device", CD->getDevStr( QComboBox_cdwriterdev->currentItem() ));
 	config->writeEntry("Index", QComboBox_cdwriterdev->currentItem());
 	config->writeEntry("isRW", CD->isRW( QComboBox_cdwriterdev->currentItem() ));
+	config->writeEntry("BurnProof", QCheckBox_BurnProof->isChecked() );
 
 	//Save settings for CD-Reader
 	config->setGroup("CD-Reader");
